@@ -54,6 +54,7 @@ import time
 import inspect
 import keyword
 import tokenize
+import warnings
 from optparse import OptionParser
 from fnmatch import fnmatch
 try:
@@ -62,7 +63,7 @@ try:
 except ImportError:
     from ConfigParser import RawConfigParser
 
-__version__ = '1.7.0'
+__version__ = '1.7.1'
 
 DEFAULT_EXCLUDE = '.svn,CVS,.bzr,.hg,.git,__pycache__,.tox'
 DEFAULT_IGNORE = 'E121,E123,E126,E226,E24,E704'
@@ -2115,7 +2116,19 @@ def _parse_multi_options(options, split_token=','):
 
 
 def _main():
-    """Parse options and run checks on Python source."""
+    """Parse options and run checks on Python source.
+
+    Warn of deprecation and advise users to switch to pycodestyle.
+    """
+    warnings.warn(
+        '\n\n'
+        'pep8 has been renamed to pycodestyle (GitHub issue #466)\n'
+        'Use of the pep8 tool will be removed in a future release.\n'
+        'Please install and use `pycodestyle` instead.\n\n'
+        '$ pip install pycodestyle\n'
+        '$ pycodestyle ...\n'
+    )
+
     import signal
 
     # Handle "Broken pipe" gracefully
@@ -2147,5 +2160,6 @@ def _main():
             sys.stderr.write(str(report.total_errors) + '\n')
         sys.exit(1)
 
+
 if __name__ == '__main__':
     _main()
